==> pegasus-member-api-1.0-20161214.072041-1-sources.jar: com/thebeastshop/member/point/cron/MemberCommonPointCron.java <==
package com.thebeastshop.member.point.cron;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 添加会员积分 使用的积分    参数
 * create by com.thebeastshop.member.point.cron member :author lijing
 * User:lijing
 * DATE : 2016/12/14
 * TIME : 14:18
 * member.
 */
public class MemberCommonPointCron implements Serializable {
    /**会员积分id*/
    private Long memberId;
    /**会员积分code*/
    private String memberCode;
    /**当前时间 不需要传入*/
    private Date now = new Date();
    /**会员你积分类型，  请参照  MemberPointConstant 接口中的 Pont_Type_Id  这个 接口中的参数*/
    private Integer memberPointType;
    /**积分数 积分书 我是按照 类型来的  如果 有的类型不需要传入积分数 可以为空*/
    private BigDecimal point;

    public Long getMemberId() {
        return memberId;
    }

    public void setMemberId(Long memberId) {
        this.memberId = memberId;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public Date getNow() {
        return now;
    }

    public void setNow(Date now) {
        this.now = now;
    }

    public Integer getMemberPointType() {
        return memberPointType;
    }

    public void setMemberPointType(Integer memberPointType) {
        this.memberPointType = memberPointType;
    }

    public BigDecimal getPoint() {
        return point;
    }

    public void setPoint(BigDecimal point) {
        this.point = point;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this)
                .append("memberId", memberId)
                .append("memberCode", memberCode)
                .append("now", now)
                .append("memberPointType", memberPointType)
                .append("point", point)
                .toString();
    }
}

==> pegasus-member-api-1.0-20161215.093109-5-sources.jar: com/thebeastshop/member/point/cron/MemberCommonPointCron.java <==
package com.thebeastshop.member.point.cron;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 添加会员积分 使用的积分    参数
 * create by com.thebeastshop.member.point.cron member :author lijing
 * User:lijing
 * DATE : 2016/12/14
 * TIME : 14:18
 * member.
 */
public class MemberCommonPointCron implements Serializable {
    /**会员积分id*/
    private Long memberId;
    /**会员积分code*/
    private String memberCode;
    /**当前时间 不需要传入*/
    private Date now = new Date();
    /**会员你积分类型，  请参照  MemberPointConstant 接口中的 Pont_Type_Id  这个 接口中的参数*/
    private Integer memberPointType;
    /**积分数 积分书 我是按照 类型来的  如果 有的类型不需要传入积分数 可以为空 传入必须是大于0的数*/
    private BigDecimal point;

    public Long getMemberId() {
        return memberId;
    }

    public void setMemberId(Long memberId) {
        this.memberId = memberId;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public Date getNow() {
        return now;
    }

    public void setNow(Date now) {
        this.now = now;
    }

    public Integer getMemberPointType() {
        return memberPointType;
    }

    public void setMemberPointType(Integer memberPointType) {
        this.memberPointType = memberPointType;
    }

    public BigDecimal getPoint() {
        return point;
    }

    public void setPoint(BigDecimal point) {
        this.point = point;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this)
                .append("memberId", memberId)
                .append("memberCode", memberCode)
                .append("now", now)
                .append("memberPointType", memberPointType)
                .append("point", point)
                .toString();
    }
}
